﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using RestSharp;
using System.Net;
using System.Collections.Generic;

namespace EdFi.Ods.Labs.Tests.AddDescriptors.Solution
{
    [TestClass]
    public class When_Adding_Descriptors
    {
        [TestMethod]
        public void Should_Manage_Successfully_Under_Assigned_Namespace()
        {
            var client = SdkHelper.CreateClient(2015);
            IRestResponse response = null;
            var transportationMethodDescriptorsApi = new EdFi.Ods.Apis.TransportationMethodDescriptorsApi(client);
            EdFi.Ods.Models.TransportationMethodDescriptor transportationMethodDescriptor = null;
            List<EdFi.Ods.Models.TransportationMethodDescriptor> transportationMethodDescriptors = null;

            // Populate the required fields of the descriptor and make sure the namespace starts with the assigned namespace.
            transportationMethodDescriptor = new Models.TransportationMethodDescriptor
            {
                @namespace = "http://www.example.com/transportationMethodDescriptors",
                codeValue = "HC",
                description = "Helicopter",
                shortDescription = "Helicopter"
            };

            // Add the new descriptor and confirm success.
            response = transportationMethodDescriptorsApi.PostTransportationMethodDescriptors(transportationMethodDescriptor);

            // Should only allow a Created, but just in case this was partially run before we'll give room by accepting an OK.
            Assert.IsTrue(response.StatusCode == HttpStatusCode.Created || response.StatusCode == HttpStatusCode.OK);

            // Get all of the descriptors just to examine the result in Fiddler.
            transportationMethodDescriptors = transportationMethodDescriptorsApi.GetTransportationMethodDescriptorsAll(null, null).Data;

            Assert.IsTrue(transportationMethodDescriptors.Count > 0);

            // Remove the new descriptor and confirm success.
            response = transportationMethodDescriptorsApi.DeleteTransportationMethodDescriptorById(transportationMethodDescriptor.id, null);

            Assert.AreEqual(HttpStatusCode.NoContent, response.StatusCode);
        }

        [TestMethod]
        public void Should_Fail_Under_Different_Namespace()
        {
            var client = SdkHelper.CreateClient(2015);
            IRestResponse response = null;
            var transportationMethodDescriptorApi = new EdFi.Ods.Apis.TransportationMethodDescriptorsApi(client);
            EdFi.Ods.Models.TransportationMethodDescriptor transportationMethodDescriptor = null;

            // Populate the required fields of the descriptor and make sure the namespace prefix DOES NOT match the assigned namespace.
            transportationMethodDescriptor = new Models.TransportationMethodDescriptor
            {
                @namespace = "http://www.wrongnamespace.com/transportationMethodDescriptors",
                codeValue = "HC",
                description = "Helicopter",
                shortDescription = "Helicopter"
            };

            // Attempt to add the new descriptor and confirm error.
            response = transportationMethodDescriptorApi.PostTransportationMethodDescriptors(transportationMethodDescriptor);

            Assert.IsTrue(response.StatusCode == HttpStatusCode.Forbidden);
        }
    }
}
