﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using RestSharp;
using System.Net;
using System.Collections.Generic;
using System.IO;

namespace EdFi.Ods.Labs.Tests.AddHairColor.Solution
{
    [TestClass]
    public class When_Persisting_Hair_Color
    {
        [TestMethod]
        public void Should_Save_Successfully_Via_Transaction()
        {
            // Use the IdGenerator class to create a new UniqueId for this student.
            var studentUniqueId = IdGenerator.GenerateId();

            // Create the student object, client, Api instance, and response reference to be used throughout this method (see previous lab for an example).
            var client = SdkHelper.CreateClient(2015);
            var studentsApi = new EdFi.Ods.Apis.StudentsApi(client);
            EdFi.Ods.Models.Student student = null;
            IRestResponse response = null;
            IRestResponse<EdFi.Ods.Models.Student> studentResponse = null;
            var studentSchoolAssociationsApi = new EdFi.Ods.Apis.StudentSchoolAssociationsApi(client);
            EdFi.Ods.Models.StudentSchoolAssociation studentSchoolAssociation = null;

            // Create a student with a hair color.
            student = new Models.Student
            {
                studentUniqueId = studentUniqueId,
                firstName = "John",
                lastSurname = "Smith",
                sexType = "Male",
                birthDate = new DateTime(2006, 1, 1),
                hairColor = "Green"
            };

            response = studentsApi.PostStudents(student);

            Assert.AreEqual(HttpStatusCode.Created, response.StatusCode);

            // Store the resource Id for later use.
            var id = student.id;

            // Add a student school association.
            studentSchoolAssociation = new Models.StudentSchoolAssociation
            {
                studentReference = new Models.StudentReference { studentUniqueId = studentUniqueId },
                schoolReference = new Models.SchoolReference { schoolId = 255901001 },
                schoolYearTypeReference = new Models.SchoolYearTypeReference { schoolYear = 2011 },
                entryDate = new DateTime(2015, 1, 2),
                entryGradeLevelDescriptor = "Eleventh grade"
            };

            studentSchoolAssociationsApi.PostStudentSchoolAssociations(studentSchoolAssociation);

            // Get the student by key and compare the hair color of what was sent vs what was stored.
            studentResponse = studentsApi.GetStudentByKey(studentUniqueId, null);

            Assert.AreEqual(student.hairColor, studentResponse.Data.hairColor);
        }

        [TestMethod]
        public void Should_Save_Successfully_Via_Bulk()
        {
            // Use the IdGenerator class to create a new UniqueId for this student.
            var studentUniqueId = IdGenerator.GenerateId();

            // Create the student object, client, Api instance, and response reference to be used throughout this method (see previous lab for an example).
            var client = SdkHelper.CreateClient(2015);
            var studentsApi = new EdFi.Ods.Apis.StudentsApi(client);
            EdFi.Ods.Models.Student student = null;
            IRestResponse response = null;
            IRestResponse<EdFi.Ods.Models.Student> studentResponse = null;
            var studentSchoolAssociationsApi = new EdFi.Ods.Apis.StudentSchoolAssociationsApi(client);
            EdFi.Ods.Models.StudentSchoolAssociation studentSchoolAssociation = null;
            var interchanges = new List<Interchange>();
            var hairColor = "Red";

            // Build the content by filling in parameters required for the Xml files.
            var studentXmlContent = string.Format(File.ReadAllText(@"AddHairColor\Student.xml"),
                studentUniqueId,
                "John",
                "Smith",
                "Male",
                "1/1/2010",
                hairColor);

            interchanges.Add(new Interchange
            {
                XmlContent = studentXmlContent,
                InterchangeType = "Student"
            });

            SdkHelper.UploadInterchanges(client, interchanges);

            // Add a student school association.
            studentSchoolAssociation = new Models.StudentSchoolAssociation
            {
                studentReference = new Models.StudentReference { studentUniqueId = studentUniqueId },
                schoolReference = new Models.SchoolReference { schoolId = 255901001 },
                schoolYearTypeReference = new Models.SchoolYearTypeReference { schoolYear = 2011 },
                entryDate = new DateTime(2015, 1, 2),
                entryGradeLevelDescriptor = "Eleventh grade"
            };

            studentSchoolAssociationsApi.PostStudentSchoolAssociations(studentSchoolAssociation);

            // Get the student by key and compare the hair color of what was sent vs what was stored.
            studentResponse = studentsApi.GetStudentByKey(studentUniqueId, null);

            Assert.AreEqual(hairColor, studentResponse.Data.hairColor);
        }
    }
}
