﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using System.IO;
using System.Collections.Generic;
using RestSharp;
using System.Net;

namespace EdFi.Ods.Labs.Tests.AddNewEntity.Solution
{
    [TestClass]
    public class When_Submitting_Student_School_Transportation
    {
        [TestMethod]
        public void Should_Be_Able_To_Submit_Multiple_Files_And_Retrieve_Errors()
        {
            var client = SdkHelper.CreateClient(2015);
            var interchanges = new List<Interchange>();
            var studentUniqueId = IdGenerator.GenerateId();

            // Build the content by filling in parameters required for the Xml files.
            var studentXmlContent = string.Format(File.ReadAllText(@"SubmitBulkFiles\Student.xml"),
                studentUniqueId,
                "John",
                "Smith",
                "Male",
                "1/1/2010");

            var studentEnrollmentXmlContent = string.Format(File.ReadAllText(@"AddNewEntity\StudentEnrollment.xml"),
                studentUniqueId,
                255901001,
                "1/1/2015",
                "Bus",
                null,
                "Bus",
                null);

            interchanges.Add(new Interchange
            {
                XmlContent = studentXmlContent,
                InterchangeType = "Student"
            });

            interchanges.Add(new Interchange
            {
                XmlContent = studentEnrollmentXmlContent,
                InterchangeType = "StudentEnrollment"
            });

            SdkHelper.UploadInterchanges(client, interchanges);

            // Make sure there are no errors.
            Assert.AreEqual(0, interchanges[0].Exceptions.Count);
            Assert.AreEqual(0, interchanges[1].Exceptions.Count);
        }
    }

    [TestClass]
    public class When_Adding_A_New_Entity_Transactionally
    {
        [TestMethod]
        public void Should_Insert_Successfully()
        {
            // Use the IdGenerator class to create a new UniqueId for this student.
            var studentUniqueId = IdGenerator.GenerateId();

            // Create the objects, client, Api instances, and response references to be used throughout this method (see previous lab for an example).
            var client = SdkHelper.CreateClient(2015);
            var studentsApi = new EdFi.Ods.Apis.StudentsApi(client);
            EdFi.Ods.Models.Student student = null;
            IRestResponse response = null;
            var studentSchoolAssociationsApi = new EdFi.Ods.Apis.StudentSchoolAssociationsApi(client);
            EdFi.Ods.Models.StudentSchoolAssociation studentSchoolAssociation = null;
            var studentSchoolTransportationsApi = new EdFi.Ods.Apis.StudentSchoolTransportationsApi(client);
            EdFi.Ods.Models.StudentSchoolTransportation studentSchoolTransportation = null;


            // Create a student.
            student = new Models.Student
            {
                studentUniqueId = studentUniqueId,
                firstName = "John",
                lastSurname = "Smith",
                sexType = "Male",
                birthDate = new DateTime(2006, 1, 1)
            };

            studentsApi.PostStudents(student);

            // Add a student school association.
            studentSchoolAssociation = new Models.StudentSchoolAssociation
            {
                studentReference = new Models.StudentReference { studentUniqueId = studentUniqueId },
                schoolReference = new Models.SchoolReference { schoolId = 255901001 },
                schoolYearTypeReference = new Models.SchoolYearTypeReference { schoolYear = 2011 },
                entryDate = new DateTime(2015, 1, 2),
                entryGradeLevelDescriptor = "Eleventh grade"
            };

            response = studentSchoolAssociationsApi.PostStudentSchoolAssociations(studentSchoolAssociation);

            // Create the student school transportation record.
            studentSchoolTransportation = new Models.StudentSchoolTransportation
            {
                schoolId = studentSchoolAssociation.schoolReference.schoolId,
                studentUniqueId = studentSchoolAssociation.studentReference.studentUniqueId,
                entryDate = studentSchoolAssociation.entryDate,
                toTransportationMethodDescriptor = "Bus",
                toTransportationCode = "1234",
                fromTransportationMethodDescriptor = "Walk/Bike"
            };

            response = studentSchoolTransportationsApi.PostStudentSchoolTransportations(studentSchoolTransportation);

            Assert.AreEqual(HttpStatusCode.Created, response.StatusCode);
        }
    }
}
