﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using RestSharp;
using System.Net;

namespace EdFi.Ods.Labs.Tests.ManageStudents.Solution
{
    [TestClass]
    public class When_Managing_Students
    {
        [TestMethod]
        public void Should_Have_Access_Errors_Without_An_Association()
        {
            // Use the IdGenerator class to create a new UniqueId for this student.
            var studentUniqueId = IdGenerator.GenerateId();

            // Create the student object, client, Api instance, and response reference to be used throughout this method (see previous lab for an example).
            var client = SdkHelper.CreateClient(2015);
            var studentsApi = new EdFi.Ods.Apis.StudentsApi(client);
            EdFi.Ods.Models.Student student = null;
            IRestResponse response = null;
            IRestResponse<EdFi.Ods.Models.Student> studentResponse = null;

            // Create a student.
            student = new Models.Student
            {
                studentUniqueId = studentUniqueId,
                firstName = "John",
                lastSurname = "Smith",
                sexType = "Male",
                birthDate = new DateTime(2006, 1, 1)
            };

            response = studentsApi.PostStudents(student);

            Assert.AreEqual(HttpStatusCode.Created, response.StatusCode);

            // Store the resource Id for later use.
            var id = student.id;

            // Read the student using GetByKey.
            studentResponse = studentsApi.GetStudentByKey(studentUniqueId, null);

            Assert.AreEqual(HttpStatusCode.Forbidden, studentResponse.StatusCode);

            // Change the name and try to update the student.
            student.id = null;
            student.firstName = "Bob";

            response = studentsApi.PostStudents(student);

            Assert.AreEqual(HttpStatusCode.Forbidden, studentResponse.StatusCode);

            // Delete the student.
            response = studentsApi.DeleteStudentById(id, null);

            Assert.AreEqual(HttpStatusCode.NoContent, response.StatusCode);

            // Execute a GetByKey to ensure the student has been removed.
            studentResponse = studentsApi.GetStudentByKey(studentUniqueId, null);

            Assert.AreEqual(HttpStatusCode.NotFound, studentResponse.StatusCode);
        }

        [TestMethod]
        public void Should_Have_Success_With_An_Association()
        {
            // Use the IdGenerator class to create a new UniqueId for this student.
            var studentUniqueId = IdGenerator.GenerateId();

            // Create the student object, client, Api instance, and response reference to be used throughout this method (see previous lab for an example).
            var client = SdkHelper.CreateClient(2015);
            var studentsApi = new EdFi.Ods.Apis.StudentsApi(client);
            EdFi.Ods.Models.Student student = null;
            IRestResponse response = null;
            IRestResponse<EdFi.Ods.Models.Student> studentResponse = null;
            var studentSchoolAssociationsApi = new EdFi.Ods.Apis.StudentSchoolAssociationsApi(client);
            EdFi.Ods.Models.StudentSchoolAssociation studentSchoolAssociation = null;
            IRestResponse<EdFi.Ods.Models.StudentSchoolAssociation> studentSchoolAssociationResponse = null;

            // Create a student.
            student = new Models.Student
            {
                studentUniqueId = studentUniqueId,
                firstName = "John",
                lastSurname = "Smith",
                sexType = "Male",
                birthDate = new DateTime(2006, 1, 1)
            };

            response = studentsApi.PostStudents(student);

            Assert.AreEqual(HttpStatusCode.Created, response.StatusCode);

            // Store the resource Id for later use.
            var id = student.id;

            // Add a student school association.
            studentSchoolAssociation = new Models.StudentSchoolAssociation
            {
                studentReference = new Models.StudentReference { studentUniqueId = studentUniqueId },
                schoolReference = new Models.SchoolReference { schoolId = 255901001 },
                schoolYearTypeReference = new Models.SchoolYearTypeReference { schoolYear = 2011 },
                entryDate = new DateTime(2015, 1, 2),
                entryGradeLevelDescriptor = "Eleventh grade"
            };

            response = studentSchoolAssociationsApi.PostStudentSchoolAssociations(studentSchoolAssociation);

            Assert.AreEqual(HttpStatusCode.Created, response.StatusCode);

            // Read the student using GetByKey.
            studentResponse = studentsApi.GetStudentByKey(studentUniqueId, null);

            Assert.AreEqual(HttpStatusCode.OK, studentResponse.StatusCode);

            // Change the name and try to update the student.
            student.id = null;
            student.firstName = "Bob";

            response = studentsApi.PostStudents(student);

            Assert.AreEqual(HttpStatusCode.OK, studentResponse.StatusCode);

            // Delete the student.
            response = studentsApi.DeleteStudentById(id, null);

            Assert.AreEqual(HttpStatusCode.Conflict, response.StatusCode);

            // Delete the student school association.
            response = studentSchoolAssociationsApi.DeleteStudentSchoolAssociationById(studentSchoolAssociation.id, null);

            Assert.AreEqual(HttpStatusCode.NoContent, response.StatusCode);

            // Try to delete the student again.
            response = studentsApi.DeleteStudentById(id, null);

            Assert.AreEqual(HttpStatusCode.NoContent, response.StatusCode);
        }
    }
}
