﻿using System;
using Microsoft.VisualStudio.TestTools.UnitTesting;
using RestSharp;
using System.Net;

namespace EdFi.Ods.Labs.Tests.Sections.Solution
{
    [TestClass]
    public class When_Managing_Sections
    {
        [TestMethod]
        public void Should_Be_Able_To_CRUD_A_Section()
        {
            var client = SdkHelper.CreateClient(2015);
            var sectionsApi = new EdFi.Ods.Apis.SectionsApi(client);
            EdFi.Ods.Models.Section section = null;
            IRestResponse response = null;
            IRestResponse<EdFi.Ods.Models.Section> sectionResponse = null;

            // Add a section
            section = new Models.Section
            {
                classPeriodReference = new Models.ClassPeriodReference { schoolId = 255901001, name = "01 - Traditional" },
                courseOfferingReference = new Models.CourseOfferingReference { schoolId = 255901001, localCourseCode = "03100500", schoolYear = 2011, termDescriptor = "Spring Semester" },
                locationReference = new Models.LocationReference { schoolId = 255901001, classroomIdentificationCode = "120" },
                schoolReference = new Models.SchoolReference { schoolId = 255901001 },
                uniqueSectionCode = "Unique123",
                sequenceOfCourse = 4
            };

            response = sectionsApi.PostSections(section);

            // We are allowing a Created or OK here in the event that a section gets created, but not deleted. In 
            // this case, we will be modifying the section which will generate an OK response.
            Assert.IsTrue(response.StatusCode == HttpStatusCode.Created || response.StatusCode == HttpStatusCode.OK);

            // Store the resource Id for later use. This was automatically populated for us when we executed the POST.
            var id = section.id;

            // Modify the section by changing the available credits to 10.
            section.id = null;
            section.availableCredits = 10;

            response = sectionsApi.PostSections(section);

            Assert.AreEqual(HttpStatusCode.OK, response.StatusCode);

            // Get the section by key and ensure that it is not null. You will need to use the "Data" property of the GetByKey response.
            // null can be used for the ifNoneMatch parameter.
            section = sectionsApi.GetSectionByKey(255901001, "01 - Traditional", "120", "03100500", "Spring Semester", 2011, "Unique123", 4, null).Data;
            
            Assert.IsNotNull(section);
            Assert.AreEqual(10, section.availableCredits);

            // Get the section by Id and ensure that it is not null.
            sectionResponse = sectionsApi.GetSectionsById(section.id, null);
            section = sectionResponse.Data;

            Assert.IsNotNull(section.id);
            Assert.AreEqual(HttpStatusCode.OK, sectionResponse.StatusCode);

            // Delete the section.
            response = sectionsApi.DeleteSectionById(section.id, null);

            Assert.AreEqual(HttpStatusCode.NoContent, response.StatusCode);

            // Get by Id again to make sure it no longer exists.
            sectionResponse = sectionsApi.GetSectionsById(section.id, null);
            section = sectionResponse.Data;

            Assert.IsNull(section.id);
            Assert.AreEqual(HttpStatusCode.NotFound, sectionResponse.StatusCode);
        }
    }
}
