using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.Ods.Models {
  public class CourseTranscript {
    /* The unique identifier of the resource. */
    public string id { get; set; }

    /* A reference to the related Course resource. */
    public CourseReference courseReference { get; set; }

    /* A reference to the related School resource. */
    public SchoolReference schoolReference { get; set; }

    /* A reference to the related StudentAcademicRecord resource. */
    public StudentAcademicRecordReference studentAcademicRecordReference { get; set; }

    /* The result from the student''s attempt to take the course, for example:  Pass  Fail  Incomplete  Withdrawn  Expelled */
    public string courseAttemptResultType { get; set; }

    /* Key for Credit */
    public string attemptedCreditType { get; set; }

    /* Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units. */
    public double? attemptedCreditConversion { get; set; }

    /* The number of credits attempted for a course. */
    public double? attemptedCredits { get; set; }

    /* Key for Credit */
    public string earnedCreditType { get; set; }

    /* Conversion factor that when multiplied by the number of credits is equivalent to Carnegie units. */
    public double? earnedCreditConversion { get; set; }

    /* The number of credits awarded or earned for the course. */
    public double? earnedCredits { get; set; }

    /* A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table.   */
    public string whenTakenGradeLevelDescriptor { get; set; }

    /* The method the credits were earned, for example:  Classroom, Examination, Transfer */
    public string methodCreditEarnedType { get; set; }

    /* The final indicator of student performance in a class as submitted by the instructor. */
    public string finalLetterGradeEarned { get; set; }

    /* The final indicator of student performance in a class as submitted by the instructor. */
    public double? finalNumericGradeEarned { get; set; }

    /* Indicates that an academic course has been repeated by a student and how that repeat is to be computed in the student''s academic grade average. */
    public string courseRepeatCodeType { get; set; }

    /* The descriptive name given to a course of study offered in a school or other institution or organization. In departmentalized classes at the elementary, secondary, and postsecondary levels (and for staff development activities), this refers to the name by which a course is identified (e.g., American History, English III). For elementary and other non-departmentalized classes, it refers to any portion of the instruction for which a grade or report is assigned (e.g., reading, composition, spelling, and language arts). */
    public string courseTitle { get; set; }

    /* The descriptive name given to a course of study offered in the school, if different from the CourseTitle. */
    public string alternativeCourseTitle { get; set; }

    /* The local code assigned by the school that identifies the course offering, the code from an external educational organization, or other alternate course code. */
    public string alternativeCourseCode { get; set; }

    /* An unordered collection of courseTranscriptEarnedAdditionalCredits.  This entity is the final record of a student's performance in their courses at the end of a semester or school year. */
    public List<CourseTranscriptEarnedAdditionalCredits> earnedAdditionalCredits { get; set; }

    /* A unique system-generated value that identifies the version of the resource. */
    public string _etag { get; set; }

    }
}
