using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.Ods.Models {
  public class GradeReference {
    /* The name of the grading period during the school year in which the grade is offered (e.g., 1st cycle, 1st semester) */
    public string gradingPeriodDescriptor { get; set; }

    /* Month, day, and year of the first day of the grading period. */
    public DateTime? gradingPeriodBeginDate { get; set; }

    /* The type of grade (e.g., Exam, Final, Grading Period, Progress Report) */
    public string type { get; set; }

    /* A unique alpha-numeric code assigned to a student. */
    public string studentUniqueId { get; set; }

    /* School Identity Column   */
    public int? schoolId { get; set; }

    /* An indication of the portion of a typical daily session in which students receive instruction in a specified subject (e.g., morning, sixth period, block period or AB schedules).  = */
    public string classPeriodName { get; set; }

    /* A unique number or alphanumeric code assigned to a room by a school, school system, state, or other agency or entity. */
    public string classroomIdentificationCode { get; set; }

    /* The local code assigned by the LEA or Campus that identifies the organization of subject matter and related learning experiences provided for the instruction of students. */
    public string localCourseCode { get; set; }

    /* A unique identifier for the section, that is defined for a campus by the classroom, the subjects taught, and the instructors that are assigned.  NEDM: Unique Course Code */
    public string uniqueSectionCode { get; set; }

    /* When a section is part of a sequence of parts for a course, the number if the sequence.  If the course has only onle part, the value of this section attribute should be 1. */
    public int? sequenceOfCourse { get; set; }

    /* The identifier for the school year. */
    public int? schoolYear { get; set; }

    /* A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table. */
    public string termDescriptor { get; set; }

    /* Month, day, and year of the Student's entry or assignment to the Section. */
    public DateTime? beginDate { get; set; }

    /* Represents a hyperlink to the related grade resource. */
    public Link link { get; set; }

    }
}
