using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.Ods.Models {
  public class LearningStandard {
    /* The unique identifier of the resource. */
    public string id { get; set; }

    /* A unique number or alphanumeric code assigned to a Learning Standard. */
    public string learningStandardId { get; set; }

    /* The Identifier for the specific learning standard (e.g., 111.15.3.1.A) */
    public string parentLearningStandardId { get; set; }

    /* A detailed description of the entity. */
    public string description { get; set; }

    /* A code designated by the promulgating body to identify the statement, e.g. 1.N.3 (usually not globally unique). */
    public string itemCode { get; set; }

    /* The public web site address (URL), file, or ftp locator. */
    public string uri { get; set; }

    /* Subject area for the learning standard. */
    public string academicSubjectDescriptor { get; set; }

    /* The descriptive name given to a course of study offered in a school or other institution or organization. In departmentalized classes at the elementary, secondary, and postsecondary levels (and for staff development activities), this refers to the name by which a course is identified (e.g., American History, English III). For elementary and other non-departmentalized classes, it refers to any portion of the instruction for which a grade or report is assigned (e.g., reading, composition, spelling, and language arts). */
    public string courseTitle { get; set; }

    /* One or more statements that describes the criteria used by teachers and students to check for attainment of a learning standard. This criteria gives clear indications as to the degree to which learning is moving through the Zone or Proximal Development toward independent achievement of the LearningStandard. */
    public string successCriteria { get; set; }

    /* Namespace for the LearningStandard. */
    public string @namespace { get; set; }

    /* This entity is a sub-element of a learning objective consisting of a precise statement of the expectation of a student's proficiency. */
    public LearningStandardContentStandard contentStandard { get; set; }

    /* An unordered collection of learningStandardGradeLevels.  This entity is a sub-element of a learning objective consisting of a precise statement of the expectation of a student's proficiency. */
    public List<LearningStandardGradeLevel> gradeLevels { get; set; }

    /* An unordered collection of learningStandardIdentificationCodes.  This entity is a sub-element of a learning objective consisting of a precise statement of the expectation of a student's proficiency. */
    public List<LearningStandardIdentificationCode> identificationCodes { get; set; }

    /* An unordered collection of learningStandardPrerequisiteLearningStandards.  This entity is a sub-element of a learning objective consisting of a precise statement of the expectation of a student's proficiency. */
    public List<LearningStandardPrerequisiteLearningStandard> prerequisiteLearningStandards { get; set; }

    /* A unique system-generated value that identifies the version of the resource. */
    public string _etag { get; set; }

    }
}
