using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.Ods.Models {
  public class Session {
    /* The unique identifier of the resource. */
    public string id { get; set; }

    /* A reference to the related School resource. */
    public SchoolReference schoolReference { get; set; }

    /* A reference to the related SchoolYearType resource. */
    public SchoolYearTypeReference schoolYearTypeReference { get; set; }

    /* A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table. */
    public string termDescriptor { get; set; }

    /* The identifier for the calendar for the academic session (e.g., 2010/11, 2011 Summer).  NEDM: Session Type */
    public string name { get; set; }

    /* Month, day, and year of the first day of the Session. */
    public DateTime? beginDate { get; set; }

    /* Month, day, and year of the last day of the Session. */
    public DateTime? endDate { get; set; }

    /* The total number of instructional days in the school calendar. */
    public int? totalInstructionalDays { get; set; }

    /* An unordered collection of sessionAcademicWeeks.  This entity represents the prescribed span of time when an education institution is open, instruction is provided and students are under the direction and guidance of teachers and/or education institution administration. A session may be interrupted by one or more vacations. */
    public List<SessionAcademicWeek> academicWeeks { get; set; }

    /* An unordered collection of sessionGradingPeriods.  This entity represents the prescribed span of time when an education institution is open, instruction is provided and students are under the direction and guidance of teachers and/or education institution administration. A session may be interrupted by one or more vacations. */
    public List<SessionGradingPeriod> gradingPeriods { get; set; }

    /* A unique system-generated value that identifies the version of the resource. */
    public string _etag { get; set; }

    }
}
