using System;
using System.Text;
using System.Collections;
using System.Collections.Generic;

namespace EdFi.Ods.Models {
  public class StudentCTEProgramAssociation {
    /* The unique identifier of the resource. */
    public string id { get; set; }

    /* A unique alpha-numeric code assigned to a student. */
    public string studentUniqueId { get; set; }

    /* The education organization where the student is participating in or receiving the program services. */
    public int? educationOrganizationId { get; set; }

    /* The program associated with the student. */
    public string programType { get; set; }

    /* The formal name of the program of instruction, training, services or benefits available through federal, state, or local agencies. */
    public string programName { get; set; }

    /* The education organization where the student is participating in or receiving the program services. */
    public int? programEducationOrganizationId { get; set; }

    /* The month, day, and year on which the Student first received services. */
    public DateTime? beginDate { get; set; }

    /* The month, day, and year on which the Student exited the Program or stopped receiving services. */
    public DateTime? endDate { get; set; }

    /* A unique identifier used as Primary Key, not derived from business logic, when acting as Foreign Key, references the parent table. */
    public string reasonExitedDescriptor { get; set; }

    /* Indicates whether the Student received services during the summer session or between sessions. */
    public bool? servedOutsideOfRegularSession { get; set; }

    /* An unordered collection of studentProgramAssociationServices.  This association represents the career and technical education (CTE) program that a student participates in. The association is an extension of the StudentProgramAssociation particular for CTE programs. */
    public List<StudentProgramAssociationService> services { get; set; }

    /* An unordered collection of studentCTEProgramAssociationCTEPrograms.  This association represents the career and technical education (CTE) program that a student participates in. The association is an extension of the StudentProgramAssociation particular for CTE programs. */
    public List<StudentCTEProgramAssociationCTEProgram> ctePrograms { get; set; }

    /* A unique system-generated value that identifies the version of the resource. */
    public string _etag { get; set; }

    }
}
